#include <algorithm>
#include <stdio.h>
#include <vector>

/* Undirected edge between u and v with weight w. */
struct Edge {
  int u, v, w;

  Edge(int u, int v, int w) : u(u), v(v), w(w) { }

  /* Comparison function to order in non-decreasing order of weights. */
  bool operator<(const Edge& e) const {
    return w < e.w;
  }
};


/* Implementation of the union-find data structure. */
struct UnionFind {
  /* The parent of the node. */
  std::vector<int> parent;
  /* The size of the component rooted at that node. 
     (only valid if this is the root. */
  std::vector<int> sz;

  int findParent(int x) {
    if (parent[x] == x) return x;
    return parent[x] = findParent(parent[x]);
  }

  bool areConnected(int a, int b) {
    int pA = findParent(a), pB = findParent(b);
    return pA == pB;
  }

  void unite(int a, int b) {
    int pA = findParent(a), pB = findParent(b);
    if (pA == pB) return;

    if (sz[pA] < sz[pB]) {
      parent[pA] = pB;
    } else {
      parent[pB] = pA;
      if (sz[pA] == sz[pB]) ++sz[pA];
    }
  }

  UnionFind(int n) : parent(n, 0), sz(n, 0) {
    for (int i = 0; i < n; ++i) {
      parent[i] = i;
    }
  }
};

int main() {
  int n, m;
  scanf("%d%d", &n, &m);

  std::vector<Edge> edges;

  for (int i = 0; i < m; ++i) {
    int a, b, c;
    scanf("%d%d%d", &a, &b, &c);
    --a; --b; // Make the nodes zero based.
    edges.push_back(Edge(a, b, c));
  }

  /* Main Kruskal's implementation starts here. */
  std::sort(edges.begin(), edges.end());

  UnionFind union_find(n);

  long long total_cost = 0;
  for (const auto edge : edges) {
    if (!union_find.areConnected(edge.u, edge.v)) {
      union_find.unite(edge.u, edge.v);
      total_cost += edge.w;
    }
  }
  printf("%lld\n", total_cost);

  return 0;
}
